summaryrefslogtreecommitdiff
path: root/indra/llcommon/llmainthreadtask.h
diff options
context:
space:
mode:
Diffstat (limited to 'indra/llcommon/llmainthreadtask.h')
-rw-r--r--indra/llcommon/llmainthreadtask.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/indra/llcommon/llmainthreadtask.h b/indra/llcommon/llmainthreadtask.h
index cec95b2356..c3ed7fef52 100644
--- a/indra/llcommon/llmainthreadtask.h
+++ b/indra/llcommon/llmainthreadtask.h
@@ -89,10 +89,10 @@ private:
}
// Given arbitrary CALLABLE, which might be a lambda, how are we
// supposed to obtain its signature for std::packaged_task? It seems
// redundant to have to add an argument list to engage result_of, then
// add the argument list again to complete the signature. At least we
// only support a nullary CALLABLE.
- std::packaged_task<typename std::result_of<CALLABLE()>::type()> mTask;
+ std::packaged_task<std::invoke_result_t<CALLABLE>()> mTask;
};
};
@@ -89,10 +89,10 @@ private:
// Given arbitrary CALLABLE, which might be a lambda, how are we
// supposed to obtain its signature for std::packaged_task? It seems
- // redundant to have to add an argument list to engage result_of, then
+ // redundant to have to add an argument list to engage invoke_result_t, then
// add the argument list again to complete the signature. At least we
// only support a nullary CALLABLE.